@@ -6,12 +6,13 @@ use warnings;
 use HTTP::Daemon;
 use HTTP::Message::PSGI qw(res_from_psgi);
 use Test::TCP qw(wait_port);
+use URI;
 use Time::HiRes ();
 use Scalar::Util qw(blessed weaken);
 use Carp qw(croak);
 use Exporter qw(import);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 $VERSION = eval $VERSION;
 
 our @EXPORT = qw(run_http_server);
@@ -65,7 +66,18 @@ sub run {
 
 sub port {
     my $self = shift;
-    return $self->{server} ? $self->{server}->port : 0;
+    return $self->endpoint->port;
+}
+
+sub host_port {
+    my $self = shift;
+    return $self->endpoint->host_port;
+}
+
+sub endpoint {
+    my $self = shift;
+    my $url = sprintf 'http://127.0.0.1:%d', $self->{server} ? $self->{server}->port : 0;
+    return URI->new($url);
 }
 
 sub _is_win32 { $^O eq 'MSWin32' }
@@ -107,6 +119,8 @@ Test::Fake::HTTPD - a fake HTTP server
 
 =head1 SYNOPSIS
 
+DSL-style
+
     use Test::Fake::HTTPD;
 
     my $httpd = run_http_server {
@@ -121,46 +135,119 @@ Test::Fake::HTTPD - a fake HTTP server
         return [ 200, [ 'Content-Type' => 'text/plain' ], [ 'Hello World' ] ];
     };
 
+    printf "You can connect to your server at %s.\n", $httpd->host_port;
+    # or
     printf "You can connect to your server at 127.0.0.1:%d.\n", $httpd->port;
 
+    # access to fake HTTP server
+    use LWP::UserAgent;
+    my $res = LWP::UserAgent->new->get($httpd->endpoint); # "http://127.0.0.1:{port}"
+
+    # Stop http server automatically at destruction time.
+
+OO-style
+
+    use Test::Fake::HTTPD;
+
+    my $httpd = Test::Fake::HTTPD->new(
+        timeout => 5,
+    );
+
+    $httpd->run(sub {
+        my $req = shift;
+        # ...
+        [ 200, [ 'Content-Type', 'text/plain' ], [ 'Hello World' ] ];
+    });
+
     # Stop http server automatically at destruction time.
 
 =head1 DESCRIPTION
 
 Test::Fake::HTTPD is a fake HTTP server module for testing.
 
-=head1 METHODS
-
-=over 4
-
-=item new( %args )
-
-Returns a new instance.
-
-=item run( $app_coderef )
-
-Starts this HTTP server.
-
-=item port
-
-Returns a port number of running.
-
-=back
-
 =head1 FUNCTIONS
 
 =over 4
 
-=item run_http_server
+=item * C<run_http_server { ... }>
 
 Starts HTTP server and returns the guard instance.
 
   my $httpd = run_http_server {
       my $req = shift;
       # ...
-      return $res;
+      return $http_or_plack_or_psgi_res;
   };
 
+  # can use $httpd guard object, same as OO-style
+  LWP::UserAgent->new->get($httpd->endpoint);
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+=item * C<new( %args )>
+
+Returns a new instance.
+
+  my $httpd = Test::Fake::HTTPD->new(%args);
+
+C<%args> are:
+
+=over 8
+
+=item * C<timeout>
+
+timeout value (default: 5)
+
+=item * C<listen>
+
+queue size for listen (default: 5)
+
+=item * C<port>
+
+local bind port number (default: auto detection)
+
+=back
+
+  my $httpd = Test::Fake::HTTPD->new(
+      timeout => 10,
+      listen  => 10,
+      port    => 3333,
+  );
+
+=item * C<run( sub { ... } )>
+
+Starts this HTTP server.
+
+  $httpd->run(sub { ... });
+
+=item * C<port>
+
+Returns a port number of running.
+
+  my $port = $httpd->port;
+
+=item * C<host_port>
+
+Returns a URI host_port of running. ("127.0.0.1:{port}")
+
+  my $host_port = $httpd->host_port;
+
+=item * C<endpoint>
+
+Returns an endpoint URI of running. ("http://127.0.0.1:{port}" URI object)
+
+  use LWP::UserAgent;
+
+  my $res = LWP::UserAgent->new->get($httpd->endpoint);
+
+  my $url = $httpd->endpoint;
+  $url->path('/foo/bar');
+  my $res = LWP::UserAgent->new->get($url);
+
 =back
 
 =head1 AUTHOR
